@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module WithinHelpers
   def with_scope(locator)
     locator ? within(locator) { yield } : yield
@@ -38,7 +40,7 @@ end
 Then /^(?:|I )should see \/([^\/]*)\/(?: within "([^"]*)")?$/ do |regexp, selector|
   regexp = Regexp.new(regexp)
   with_scope(selector) do
-    expect(page).to have_xpath("//*", :text => regexp)
+    expect(page).to have_xpath("//*", text: regexp)
   end
 end
 
@@ -51,10 +53,21 @@ end
 Then /^(?:|I )should not see \/([^\/]*)\/(?: within "([^"]*)")?$/ do |regexp, selector|
   regexp = Regexp.new(regexp)
   with_scope(selector) do
-    expect(page).to have_no_xpath("//*", :text => regexp)
+    expect(page).to have_no_xpath("//*", text: regexp)
   end
 end
 
+# the default in our settings is still to check unvisible content
+# as well and until we change that these steps similar to "should (not)
+# see" are necessary
+Then "{string} should be visible" do |text|
+  expect(page).to have_content(:visible, text)
+end
+
+Then "{string} should not be visible" do |text|
+  expect(page).to have_no_content(:visible, text)
+end
+
 Then /^show me the page$/ do
   save_and_open_page # rubocop:disable Lint/Debugger
 end
