@@ -1,11 +1,22 @@
+# frozen_string_literal: true
+
 require "helper"
 
 describe SimpleCov::Result do
   subject do
     original_result = {
-      source_fixture("sample.rb") => [nil, 1, 1, 1, nil, nil, 1, 1, nil, nil],
-      source_fixture("app/models/user.rb") => [nil, 1, 1, 1, nil, nil, 1, 0, nil, nil],
-      source_fixture("app/controllers/sample_controller.rb") => [nil, 2, 2, 0, nil, nil, 0, nil, nil, nil],
+      source_fixture("sample.rb") => {
+        "lines" => [nil, 1, 1, 1, nil, nil, 1, 1, nil, nil],
+        "branches" => {}
+      },
+      source_fixture("app/models/user.rb") => {
+        "lines" => [nil, 1, 1, 1, nil, nil, 1, 0, nil, nil],
+        "branches" => {}
+      },
+      source_fixture("app/controllers/sample_controller.rb") => {
+        "lines" => [nil, 2, 2, 0, nil, nil, 0, nil, nil, nil],
+        "branches" => {}
+      }
     }
     SimpleCov::Result.new(original_result).files
   end
@@ -18,16 +29,16 @@ describe SimpleCov::Result do
     expect(subject.missed_lines).to eq(3)
   end
 
-  it "has 19 never lines" do
-    expect(subject.never_lines).to eq(19)
+  it "has 17 never lines" do
+    expect(subject.never_lines).to eq(17)
   end
 
   it "has 14 lines of code" do
     expect(subject.lines_of_code).to eq(14)
   end
 
-  it "has 3 skipped lines" do
-    expect(subject.skipped_lines).to eq(3)
+  it "has 5 skipped lines" do
+    expect(subject.skipped_lines).to eq(5)
   end
 
   it "has the correct covered percent" do
@@ -45,4 +56,4 @@ describe SimpleCov::Result do
   it "has the correct covered strength" do
     expect(subject.covered_strength).to eq(0.9285714285714286)
   end
-end if SimpleCov.usable?
+end
