@@ -2,7 +2,7 @@ $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), "..", ".."))
 require "lib/simplecov"
 SimpleCov.start { command_name "Test" }
 
-dir = File.expand_path(File.dirname(__FILE__))
+dir = __dir__
 file = File.join(dir, "generated_buddha.rb")
 code = %{
   def kill_the_buddha(z)
@@ -12,4 +12,4 @@ code = %{
 File.open(file, "w") { |f| f.print code }
 load file
 File.unlink file
-fail unless kill_the_buddha(3) == 27
+raise unless kill_the_buddha(3) == 27
