@@ -1,4 +1,8 @@
+# frozen_string_literal: true
+
 require "rspec"
+require "stringio"
+require "open3"
 # loaded before simplecov to also capture parse time warnings
 require "support/fail_rspec_on_ruby_warning"
 require "simplecov"
@@ -6,12 +10,14 @@ require "simplecov"
 SimpleCov.coverage_dir("tmp/coverage")
 
 def source_fixture(filename)
-  File.expand_path(File.join(File.dirname(__FILE__), "fixtures", filename))
+  File.join(source_fixture_base_directory, "fixtures", filename)
+end
+
+def source_fixture_base_directory
+  @source_fixture_base_directory ||= File.dirname(__FILE__)
 end
 
 # Taken from http://stackoverflow.com/questions/4459330/how-do-i-temporarily-redirect-stderr-in-ruby
-require "stringio"
-
 def capture_stderr
   # The output stream must be an IO-like object. In this case we capture it in
   # an in-memory IO object so we can return the string value. You can assign any
